[−][src]Enum ttf_parser::CFFError
A list of errors that can occur during a CFF table parsing.
Variants
NoCharStringsThe CFF table doesn't have any char strings.
InvalidOperandAn invalid operand occurred.
InvalidOperatorAn invalid operator occurred.
UnsupportedOperatorAn unsupported operator occurred.
InvalidFloatFailed to parse a float number.
InvalidOffsetSizeThe OffSize value must be in 1..4 range.
Adobe Technical Note #5176, Table 2 CFF Data Types
NestingLimitReachedSubroutines nesting is limited by 10.
Adobe Technical Note #5177 Appendix B.
ArgumentsStackLimitReachedAn arguments stack size is limited by 48 values.
Adobe Technical Note #5177 Appendix B.
InvalidArgumentsStackLengthEach operand expects a specific amount of arguments on the stack.
Usually indicates an implementation error and should not occur on valid fonts.