[−][src]Enum ttf_parser::Error
A font parsing error.
Variants
NotATrueTypeNot a TrueType data.
FontIndexOutOfBoundsThe font index is out of bounds.
TableMissing(TableName)One of the required tables is missing.
InvalidTableSize(TableName)Table has an invalid size.
NoGlyphFont doesn't have such glyph ID.
NoOutlineGlyph doesn't have an outline.
InvalidGlyphClass(u16)An invalid glyph class.
NoHorizontalMetricsNo horizontal metrics for this glyph.
NoVerticalMetricsNo vertical metrics for this glyph.
NoKerningNo kerning for this glyph.
UnsupportedTableVersion(TableName, u16)An unsupported table version.
CFFError(CFFError)A CFF table parsing error.
SliceOutOfBoundsAn attempt to slice a raw data out of bounds.
This may be caused by a bug in the library or by a malformed font.
Fields of SliceOutOfBounds