pub struct Offset16(pub u16);
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Parses an object from a raw data.
Converts the offset to usize.
Checks that offset is null.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.