Struct ttf_parser::RasterGlyphImage [−][src]
pub struct RasterGlyphImage<'a> {
pub x: i16,
pub y: i16,
pub width: u16,
pub height: u16,
pub pixels_per_em: u16,
pub format: RasterImageFormat,
pub data: &'a [u8],
}Expand description
A glyph’s raster image.
Note, that glyph metrics are in pixels and not in font units.
Fields
x: i16Horizontal offset.
y: i16Vertical offset.
width: u16Image width.
It doesn’t guarantee that this value is the same as set in the data.
height: u16Image height.
It doesn’t guarantee that this value is the same as set in the data.
pixels_per_em: u16A pixels per em of the selected strike.
format: RasterImageFormatAn image format.
data: &'a [u8]A raw image data. It’s up to the caller to decode it.